<?php
/**
 * Include and setup custom metaboxes and fields.
 *
 * @category YourThemeOrPlugin
 * @package  Metaboxes
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v2.0 (or later)
 * @link     https://github.com/webdevstudios/Custom-Metaboxes-and-Fields-for-WordPress
 */

add_filter( 'cmb_meta_boxes', 'cmb_sample_metaboxes' );
/**
 * Define the metabox and field configurations.
 *
 * @param  array $meta_boxes
 * @return array
 */
function cmb_sample_metaboxes( array $meta_boxes ) {
    global $textdomain;

	// Start with an underscore to hide fields from custom fields list
	$prefix = '_cmb_';
	
	$meta_boxes[] = array(
		'id'         => 'post_options',
		'title'      => 'Post Options',
		'pages'      => array('post'), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'show_names' => true, // Show field names on the left
		'fields'     => array(
           
			
			
			array(
                'name' => 'oembed URL for post format video',
                'desc' => 'Set Intro video',
                'id'   => $prefix . 'intro_video',
                'type'    => 'oembed',
                
            ),
			
		),
	);
	
	$meta_boxes[] = array(
		'id'         => 'service_options',
		'title'      => 'Service Options',
		'pages'      => array('qk_service'), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'show_names' => true, // Show field names on the left
		'fields'     => array(
           
			array(
                'name' => 'Icon',
                'desc' => 'Icon',
                'id'   => $prefix . 'ser_icon',
                'type'    => 'text',
				'std' => ''
                
            ),
			
			
		),
	);
	$meta_boxes[] = array(
		'id'         => 'testimonial_options',
		'title'      => 'Testimonial Options',
		'pages'      => array('testimonial'), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'show_names' => true, // Show field names on the left
		'fields'     => array(
			
			
			array(
				'name'         => __( 'Testimonial Avatar', $textdomain ),
				'desc'         => __( 'Upload your testimonial\'s  Logo.', $textdomain ),
				'id'           => $prefix . 't_logo',
				'type'         => 'file',
				'preview_size' => array( 100, 100 ), // Default: array( 50, 50 )
			),
		),
	);
	
	
	
	$meta_boxes[] = array(
		'id'         => 'client_options',
		'title'      => 'Client Options',
		'pages'      => array('client'), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'show_names' => true, // Show field names on the left
		'fields'     => array(
           
			array(
                'name' => 'Client Link',
                'desc' => 'Put your link',
                'id'   => $prefix . 'c_link',
                'type'    => 'text',
				'std' => 'http://themeforest.net'
                
            ),
			
			array(
				'name'         => __( 'Client Logo', $textdomain ),
				'desc'         => __( 'Upload your client\'s  Logo.', $textdomain ),
				'id'           => $prefix . 'c_logo',
				'type'         => 'file',
				'preview_size' => array( 100, 100 ), // Default: array( 50, 50 )
			),
		),
	);
	
	// Add other metaboxes as needed
	$meta_boxes['user_edit'] = array(
		'id'         => 'user_edit',
		'title'      => __( 'User Profile Metabox', 'cmb' ),
		'pages'      => array( 'user' ), // Tells CMB to use user_meta vs post_meta
		'show_names' => true,
		'cmb_styles' => false, // Show cmb bundled styles.. not needed on user profile page
		'fields'     => array(
			array(
				'name'    => __( 'Avatar', 'cmb' ),
				'desc'    => __( 'field description (optional)', 'cmb' ),
				'id'      => $prefix . 'avatar',
				'type'    => 'file',
				'save_id' => true,
			),
			
			array(
				'name'     => __( 'Job', 'cmb' ),
				'desc'     => __( 'Your Job (optional)', 'cmb' ),
				'id'       => $prefix . 'user_Job',
				'type'     => 'text',
				'on_front' => false,
			),
		)
	);
	return $meta_boxes;
}

add_action( 'init', 'cmb_initialize_cmb_meta_boxes', 9999 );
/**
 * Initialize the metabox class.
 */
function cmb_initialize_cmb_meta_boxes() {

	if ( ! class_exists( 'cmb_Meta_Box' ) )
		require_once 'init.php';

}
